@@ -100,8 +100,12 @@ def decipher(code,key):
     return "".join(code)
     
 def a_credits():
-    for i in open("credits.txt","r").readlines():
-        print(i,end="")
+    print("\
+=== Credits ==\
+Thank you to the repl.it community for providing such amazing services for free.\
+Thank you to Atticus Kuhn for poiting out safety concerns on the project.\
+Thank you StealthHydra179 (https://repl.it/@StealthHydra179), for being the only person who cared about programming in my school.\
+Thank you Giothecoder (https://repl.it/@Giothecoder), for being there when I needed you most.")
 
 class InvalidKey(Exception):
     pass
